# Generated by Django 2.0.5 on 2018-05-20 05:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cosmicdb', '0002_cosmicdbtreeitem_is_button'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='usersystemmessage',
            name='user',
        ),
        migrations.RemoveField(
            model_name='usersystemnotification',
            name='icon_class',
        ),
        migrations.DeleteModel(
            name='UserSystemMessage',
        ),
    ]
