{% extends 'cosmicdb/base.html' %}

{% load static cosmic_tags crispy_forms_tags %}

{% block style %}

    {{ block.super }}

    body {
        background-color: #DADADA;
    }
    body > .grid {
        height: 100%;
    }
    .image {
        margin-top: -100px;
    }
    .column {
        max-width: 450px;
    }
    .content-container{
        padding: 40px;
    }

{% endblock %}

{% block content %}
    <div class="ui centered grid">
        <div class="column">
            <div class="row" style="text-align: center;">
                <h2 class="ui primary image header">
                    <img src="{% static 'cosmicdb/img/icon300.png' %}" class="image"> {% get_site_title %}
                </h2>
            </div>
            <div class="row">
                {% crispy form %}
                <a href="{% url 'password_reset' %}">I forgot my password</a>
                {% if signup_allowed %}
                    <div class="ui horizontal divider">
                        Or
                    </div>
                    <a href="{% url 'signup' %}" class="ui fluid large primary submit button" style="margin-top: 10px;">Sign Up</a>
                {% endif %}
            </div>
        </div>
    </div>
{% endblock %}

{% block footer %}
    {% include 'cosmicdb/footer.html' %}
{% endblock %}
