{% load sitetree %}
{% if sitetree_items|length_is:"1" %}
{% else %}
<div class="ui breadcrumb">
    {% for item in sitetree_items %}
        {% if not forloop.last %}
            <a href="{% sitetree_url for item %}" class="section">{% if item.url == "notifications" %}Notifications{% else %}{{ item.title_resolved|safe }}{% endif %}</a> <div class="divider"> / </div>
        {% else %}
            <li class="active section">{{ item.title_resolved|safe }}</li>
        {% endif %}
    {% endfor %}
</div>
{% endif %}