# Generated by Django 2.0.5 on 2018-05-20 05:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cosmicdb', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='cosmicdbtreeitem',
            name='is_button',
            field=models.BooleanField(default=False),
        ),
    ]
